==> 0.9.1.tar.gz: example/db_repository.dart <==
import 'package:nosql_repository/nosql_repository.dart';

/// Simulates a repository to an entity type
/// by storing instances into a map instead of a real
/// database.
class DbRepository<T> extends Repository<T> {
  final String collectionName;
  static int _latestKey = 0;
  static final Map<String, Map<String, dynamic>> _storedMaps = {};

  DbRepository(this.collectionName);

  @override
  Future<Map<String, dynamic>> create(
    Map<String, dynamic> map,
    DbPrincipal principal, [
    String? permission,
  ]) async {
    print(
        '''This method would create the map in the database, in the $collectionName collection.
           It would fail if the [permission] parameter is set and the user principal does not
           have that permission.
           It would add ownership information to the collection, like for instance
           the tenantKey of the user principal.
        ''');
    if (permission != null && !principal.hasPermission(permission)) {
      throw Error();
    }
    final key = (++_latestKey).toString();
    map['_key'] = key;
    _storedMaps[key] = map;
    return map;
  }

  @override
  Future delete(String key, DbPrincipal principal, [String? permission]) async {
    _storedMaps.remove(key);
  }

  @override
  Future<Map<String, dynamic>> get(String key, DbPrincipal principal,
      [String? permission]) async {
    return Future.value(_storedMaps[key]);
  }

  @override
  Stream<Map<String, dynamic>> getAll(DbPrincipal principal,
      [String? permission]) async* {
    for (var item in _storedMaps.values) {
      yield item;
    }
  }

  @override
  Stream<Map<String, dynamic>> runQuery(String query, DbPrincipal principal,
      {Map<String, dynamic>? parameters,
      String? collectionAlias,
      String? permission}) {
    throw UnimplementedError();
  }

  @override
  Future<Map<String, dynamic>> update(
      Map<String, dynamic> map, DbPrincipal principal,
      [String? permission]) {
    _storedMaps[map['_key']] = map;
    return Future.value(map);
  }
}

==> 1.0.0-rc.2.tar.gz: example/db_repository.dart <==
import 'package:nosql_repository/nosql_repository.dart';

/// Simulates a repository to an entity type
/// by storing instances into a map instead of a real
/// database.
class DbRepository<T> extends Repository<T> {
  final String collectionName;
  static int _latestKey = 0;
  static final Map<String, Map<String, dynamic>> _storedMaps = {};

  DbRepository(this.collectionName);

  @override
  Future<Map<String, dynamic>> create(
    Map<String, dynamic> map,
    DbPrincipal principal, [
    String? permission,
  ]) async {
    print(
        '''This method would create the map in the database, in the $collectionName collection.
           It would fail if the [permission] parameter is set and the user principal does not
           have that permission.
           It would add ownership information to the collection, like for instance
           the tenantKey of the user principal.
        ''');
    if (permission != null && !principal.hasPermission(permission)) {
      throw Error();
    }
    final key = (++_latestKey).toString();
    map['_key'] = key;
    _storedMaps[key] = map;
    return map;
  }

  @override
  Future delete(String key, DbPrincipal principal, [String? permission]) async {
    _storedMaps.remove(key);
  }

  @override
  Future<Map<String, dynamic>> get(String key, DbPrincipal principal,
      [String? permission]) async {
    return Future.value(_storedMaps[key]);
  }

  @override
  Stream<Map<String, dynamic>> getAll(DbPrincipal principal,
      [String? permission]) async* {
    for (var item in _storedMaps.values) {
      yield item;
    }
  }

  @override
  Future<Map<String, dynamic>> update(
      Map<String, dynamic> map, DbPrincipal principal,
      [String? permission]) {
    _storedMaps[map['_key']] = map;
    return Future.value(map);
  }

  @override
  Future<int> count(SearchCriteria criteria, DbPrincipal principal,
      {String permission = ''}) {
    throw UnimplementedError();
  }

  @override
  Stream<Map<String, dynamic>> search(
      SearchCriteria criteria, DbPrincipal principal,
      {String permission = ''}) {
    throw UnimplementedError();
  }

  @override
  Future<SearchResult> searchWithCount(
      SearchCriteria criteria, DbPrincipal principal,
      {String permission = ''}) {
    throw UnimplementedError();
  }
}
